@@ -1,13 +1,14 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 "Translate"
 import os
 import locale
 import gettext
 import logging
-import gtk
 import sys
 
+from gi.repository import Gtk
+
 from tryton.config import CURRENT_DIR
 
 _ = gettext.gettext
@@ -190,7 +191,7 @@ def setlang(lang=None, locale_dict=None):
 
     if locale_dict:
         conv = locale.localeconv()
-        for field in locale_dict.keys():
+        for field in list(locale_dict.keys()):
             if field == 'date':
                 continue
             conv[field] = locale_dict[field]
@@ -199,6 +200,7 @@ def setlang(lang=None, locale_dict=None):
 
 def set_language_direction(direction):
     if direction == 'rtl':
-        gtk.widget_set_default_direction(gtk.TEXT_DIR_RTL)
+        direction = Gtk.TextDirection.RTL
     else:
-        gtk.widget_set_default_direction(gtk.TEXT_DIR_LTR)
+        direction = Gtk.TextDirection.LTR
+    Gtk.Widget.set_default_direction(direction)
